// ===============================================
// This file is autogenerated - Please do not edit
// ===============================================

/* eslint-disable */



// ts client for axios
import axios, { AxiosInstance, AxiosRequestConfig } from "axios";


import {Matches, validateOrReject, IsInt, Length, MinLength, MaxLength, Min, Max} from "class-validator";
import * as _customValidators from "../customValidators";
interface CustomValidatorRule<TFunc extends (...args: any[]) => Promise<void> | void = any> {
  validator: TFunc;
  trigger: "blur";
}
interface CustomValidatorMap {
  sensitiveWord(msg: string): CustomValidatorRule<(rule: unknown, value: string) => Promise<void>>;
  htmlTextLength(
    msg: string,
    min: number,
    max: number,
  ): CustomValidatorRule<(rule: unknown, value: string) => Promise<void>>;
  elementCount(
    msg: string,
    min: number,
    max: number,
  ): CustomValidatorRule<(rule: unknown, value: Array<unknown>) => Promise<void>>;
  birthYear(msg: string, maxAge: number): CustomValidatorRule<(rule: unknown, value: number) => Promise<void>>;
  enforceTrue(msg: string): CustomValidatorRule<(rule: unknown, value: boolean) => Promise<void>>;
}

// export function htmlTextLength(msg: string, min: number, max: number) {
//     return async (rule: unknown, html: string) => {
//       const d = document.createElement("div");
//       d.innerHTML = html;
//       const text = d.textContent || "";
//       if (text.length < min || text.length > max) {
//         throw new Error(msg);
//       }
//     };
//   }

// 假如下面这一行有类型错误，就代表你需要在customValidators里面提供, ./customValidators.ts里面内容类似如下:
export const customValidators:Partial<CustomValidatorMap> = _customValidators;

export interface ValidationRuleBase {
  message?: string;
}

export interface RequiredRule extends ValidationRuleBase {
  type: "string" | "number" | "boolean" | "object" | "array";
  required?: boolean;
}

export interface RangeRule extends ValidationRuleBase {
  type: "string" | "number";
  min?: number;
  max?: number;
}

export interface RegexRule extends ValidationRuleBase {
  type: "string";
  pattern: RegExp;
}

export interface ObjectRule extends ValidationRuleBase {
  type: "object";
  fields: {[k:string]: ValidationRule[]};
}

export interface ArrayRule extends ValidationRuleBase {
  type: "array";
  defaultField: ValidationRule[];
}

export type ValidationRule = RequiredRule | RangeRule | RegexRule | ObjectRule | ArrayRule  | CustomValidatorRule; 


export function getValueByDeepPath(obj: any, path: string) {
    try {
        for (let i = 0, p = path.split("."), len = p.length; i < len; i++) {
            obj = obj[p[i]];
        }
        return obj;
    } catch (err) {
        return undefined;
    }
}

export const BASE_PATH = (() => {
    // process.env.API_BASE_PATH_RUNTIME_JS_EXPR can be any valid Javascript expression that evaluates to a 
    // (1) string, or (2) a function which after being called, returns a string that containing the API BASE PATH URL. e.g. `fhtGlobal.hosts.FhtApiRoot`;
    if (typeof process.env.API_BASE_PATH_RUNTIME_JS_EXPR=== "string") {
        const that = typeof(window) !== "undefined"? window: globalThis as any;
        const key = process.env.API_BASE_PATH_RUNTIME_JS_EXPR;
        const val = getValueByDeepPath(that, key);
        if (typeof val === "string") {
            return val;
        }
        if (typeof val === "function") {
            return val();
        }
		if(typeof window !== "undefined"){
        	if(key.length) throw new Error(`key: ${key} does not evaluate to a valid value`);
		}
    }
    // if API path is not found in window, we will use from environment variable (which is set when running webpack build)
    if (typeof process.env.API_BASE_PATH === "string") {
        return process.env.API_BASE_PATH;
    }
    return process.env.NODE_ENV === "development" ? "" : "";
})();


export function jsonReviver(key:string, value:any) {
    if (typeof value === 'string') {
        if (value.startsWith("20") && /^\d{4}-\d{2}-\d{2}/.test(value)) {
            const d= new Date(value);
            return d;
        }
    }
    return value;
}

export function pad(n: number) {
  return n < 10 ? "0" + n : n;
}

export function toISOString(d: Date) {
  return (
    d.getUTCFullYear() + "-" +
    pad(d.getUTCMonth() + 1) + "-" +
    pad(d.getUTCDate()) + "T" +
    pad(d.getUTCHours()) + ":" +
    pad(d.getUTCMinutes()) + ":" +
    pad(d.getUTCSeconds()) + "Z"
  );
}

function formatParam(p: unknown) {
  if (Object.prototype.toString.call(p) === "[object Date]") {
    return toISOString(p as Date);
  }
  return p;
}


export type AjaxMethod = "GET" | "POST" | "PUT" | "DELETE" | "OPTIONS";

export const defaultHeaders: {
    Authorization?: string, 
	"User-Agent"?: string,
} = {};

    
	
export const GLOBAL_AXIOS_CONFIG = {
	default: {} as AxiosRequestConfig,
}

export class BaseApi {
    private _client: AxiosInstance;
    /** You can set this to whatever default axios config */

    constructor(axiosInstance?: AxiosInstance) {
        this._client = axiosInstance || axios.create({
            baseURL: BASE_PATH,
            ...GLOBAL_AXIOS_CONFIG.default,
        });
    }

    /** Assert required */
    protected r(params: any, fieldNames: string[]) {
        for (const fieldName of fieldNames) {
            const value = params[fieldName];
            if (value === null || value === undefined) {
                throw new Error(`field: ${fieldName} required`);
            }
        }
    }

    protected async ajax(method: AjaxMethod, localVarPath: string, queryParameters: any, bodyDict: any): Promise<any> {
        const response = await this._client.request({
            method,
            url: localVarPath,
            params: queryParameters,
            data: bodyDict
        });
        return response.data;
    }
}


