// FHT Swagger axios client V2


// mark 2 model generic


import {Matches, validateOrReject, IsInt, Length, MinLength, MaxLength, Min, Max} from "class-validator";
import { ValidationRule  , customValidators 
 } from "../api/api";

// not an enum
export  class   AccountRegisterInputModel {
public static LABELS = {
    "Mobile": "账号",
    "Password": "密码",
    "Code": "验证码",
    "RealName": "姓名",
    "BirthYear": "出生年份",
    "Gender": "性别",
    "RegIdentityType": "身份类型",
    "RegistrationSourceType": "注册来源",
    "TermsAccepted": "服务协议",
    "Profession": "职位",
    "IndustryId": "行业",
    "AvatarUrl": "头像",
    "CompanyId": "公司ID",
    "CompanyName": "企业名称",
}
public static VALIDATORS = {
'Mobile': [

// min-max-length
     { type: "string", required: true, trigger: 'blur', message: "请输入账号" }, 
    { type: "string", min: 11, max: 11, trigger: 'blur', message: "账号必须为11个字符"},
// regex-pattern
    { type: "string", pattern: /^1[3456789]\\d{9}$/, trigger: 'blur', message: "请输入合法的账号"},
].filter(r=>r) as ValidationRule[],
'Password': [

// min-max-length
     { type: "string", required: true, trigger: 'blur', message: "请输入密码" }, 
    { type: "string", min: 6, max: 20, trigger: 'blur', message: "密码必须是6到20位"},
// regex-pattern
    { type: "string", pattern: /^\\S*$/, trigger: 'blur', message: "密码不能包含空格！"},
].filter(r=>r) as ValidationRule[],
'Code': [

// min-max-length
     { type: "string", required: true, trigger: 'blur', message: "请输入验证码" }, 
    { type: "string", min: 6, max: 6, trigger: 'blur', message: "验证码必须为6位"},
].filter(r=>r) as ValidationRule[],
'RealName': [

// min-max-length
     { type: "string", required: true, trigger: 'blur', message: "请输入姓名" }, 
    { type: "string", min: 2, max: 4, trigger: 'blur', message: "姓名必须为2到4位字符"},
// regex-pattern
    { type: "string", pattern: /^[A-Za-z0-9\\u4E00-\\u9FA5][A-Za-z0-9\\(\\)\\（\\）\\u4E00-\\u9FA5]{1,19}$/, trigger: 'blur', message: "姓名必须为2到4个汉字"},
    customValidators.sensitiveWord?.(
"姓名包含敏感词"
    ),
].filter(r=>r) as ValidationRule[],
'BirthYear': [

// min-max-range
    
    { type: "number",  min: 1900, max: 2147483647, trigger: 'blur', message: "出生年份必须不小于1900"},
    customValidators.birthYear?.(
"出生年份必须为合法的生日",
1900,
    ),
].filter(r=>r) as ValidationRule[],
'Gender': [

].filter(r=>r) as ValidationRule[],
'RegIdentityType': [

].filter(r=>r) as ValidationRule[],
'RegistrationSourceType': [

].filter(r=>r) as ValidationRule[],
'TermsAccepted': [

    customValidators.enforceTrue?.(
"服务协议必须勾选"
    ),
].filter(r=>r) as ValidationRule[],
'Profession': [

// min-max-length
     { type: "string", required: true, trigger: 'blur', message: "请输入职位" }, 
    { type: "string", min: 2, max: 10, trigger: 'blur', message: "职位必须是2到10位"},
// regex-pattern
    { type: "string", pattern: /^[A-Za-z\\u4E00-\\u9FA5]*$/, trigger: 'blur', message: "职位只允许包含中文汉字和英文字母！"},
    customValidators.sensitiveWord?.(
"职位包含敏感词"
    ),
].filter(r=>r) as ValidationRule[],
'IndustryId': [

// min-max-range
    
    { type: "number",  min: 1, max: 2147483647, trigger: 'blur', message: "行业必须不小于1"},
].filter(r=>r) as ValidationRule[],
'AvatarUrl': [

// only-max-length 
    
    { type: "string", max: 200, trigger: 'blur', message: "头像最长不超过200字"},
// regex-pattern
    { type: "string", pattern: /^[hH][tT][tT][pP][sH]?:\/\/.*$/, trigger: 'blur', message: "请输入http或https开头的url"},
].filter(r=>r) as ValidationRule[],
'CompanyId': [

// min-max-range
    
    { type: "number",  min: 1, max: 2147483647, trigger: 'blur', message: "公司Id必须为正数"},
].filter(r=>r) as ValidationRule[],
'CompanyName': [

// min-max-length
    
    { type: "string", min: 2, max: 20, trigger: 'blur', message: "企业名称必须是2到20位"},
// regex-pattern
    { type: "string", pattern: /^[A-Za-z\\u4E00-\\u9FA5][A-Za-z0-9\\(\\)\\（\\）\\u4E00-\\u9FA5]*$/, trigger: 'blur', message: "企业名称只允许是中英文、数字和小括号哦！"},
    customValidators.sensitiveWord?.(
"企业名称包含敏感词"
    ),
].filter(r=>r) as ValidationRule[],
'Region': [

].filter(r=>r) as ValidationRule[],
}
 
//a smart property
    @Matches(/^1[3456789]\\d{9}$/)
    @Length(11, 11)
 'Mobile'
: 
    string; // not enum

//a smart property
    @Matches(/^\\S*$/)
    @Length(6, 20)
 'Password'
: 
    string; // not enum

//a smart property
    @Length(6, 6)
 'Code'
: 
    string; // not enum

//a smart property
    @Matches(/^[A-Za-z0-9\\u4E00-\\u9FA5][A-Za-z0-9\\(\\)\\（\\）\\u4E00-\\u9FA5]{1,19}$/)
    @Length(2, 4)
 'RealName'
: 
    string; // not enum

//a smart property
    @Min(1900)
    @Max(2147483647)
 'BirthYear'
    ?
: 
null |
    number; // not enum

//a smart property
 'Gender'
    ?
: 
null |
    GenderEnum; //is single enum

//a smart property
 'RegIdentityType'
: 
    RegIdentityTypeEnum; //is single enum

//a smart property
 'RegistrationSourceType'
    ?
: 
null |
    RegistrationSourceTypeEnum; //is single enum

//a smart property
 'TermsAccepted'
: 
    boolean; // not enum

//a smart property
    @Matches(/^[A-Za-z\\u4E00-\\u9FA5]*$/)
    @Length(2, 10)
 'Profession'
: 
    string; // not enum

//a smart property
    @Min(1)
    @Max(2147483647)
 'IndustryId'
    ?
: 
null |
    number; // not enum

//a smart property
    @Matches(/^[hH][tT][tT][pP][sH]?:\/\/.*$/)
 'AvatarUrl'
    ?
: 
    string; // not enum

//a smart property
    @Min(1)
    @Max(2147483647)
 'CompanyId'
    ?
: 
null |
    number; // not enum

//a smart property
    @Matches(/^[A-Za-z\\u4E00-\\u9FA5][A-Za-z0-9\\(\\)\\（\\）\\u4E00-\\u9FA5]*$/)
    @Length(2, 20)
 'CompanyName'
    ?
: 
    string; // not enum

//a smart property
 'Region'
    ?
: 
    models.CoreRegionInputModel; // not enum

}
//export namespace AccountRegisterInputModel 
export enum GenderEnum {
	Male = 'Male',
	Female = 'Female'
}
export enum RegIdentityTypeEnum {
	NomalMember = 'NomalMember',
	JoinCompanyMember = 'JoinCompanyMember',
	CreateCompanyMember = 'CreateCompanyMember'
}
export enum RegistrationSourceTypeEnum {
	Web = 'Web',
	App = 'App',
	Agency = 'Agency',
	Crawler = 'Crawler'
}

