//@ts-check
/**
 * This is the version that uses ts-morph but it is rather slow right now,
 * So we are switching to fixApiModelImportsV2.js which uses native typescript compiler api.
 */

/**
 * @typedef {import("typescript").Node} Node
 * @typedef {import("typescript").SourceFile} SourceFile
 * @typedef {import("typescript").SyntaxKind} SyntaxKind
 * @typedef {import("typescript").Statement} Statement
 * @typedef {import("typescript").ImportDeclaration} ImportDeclaration
 * @typedef {import("typescript").FunctionDeclaration} FunctionDeclaration
 * @typedef {import("typescript").TransformerFactory<SourceFile>} TransformerFactory
 */

const fs = require("fs-extra");
const chalk = require("chalk");
const ts = require("typescript");
const path = require("path");
const assert = require("assert");
const util = require("util");

const debug0 = (/** @type {any} */ obj) => util.inspect(obj, { depth: 0 });
const debug1 = (/** @type {any} */ obj) => util.inspect(obj, { depth: 1 });

const nodePrinter = ts.createPrinter({ newLine: ts.NewLineKind.LineFeed });

/** @type {(src: SourceFile)=>string} */
const printSourceFile = (src) => nodePrinter.printNode(ts.EmitHint.SourceFile, src, src);

(async () => {
	const filePath = path.join(__dirname, "../tests/axios/test_axios.ts");
	assert(await fs.pathExists(filePath));
	const code = await fs.readFile(filePath, { encoding: "utf-8" });
	const sc = ts.createSourceFile(filePath, code, ts.ScriptTarget.Latest, true);

	/** @type {TransformerFactory} */
	const transformer = () => {
		return sourceFile => {
			const updated = ts.updateSourceFileNode(sourceFile, [
				...sourceFile.statements.filter(s => !ts.isImportDeclaration(s)),
			]);
			return updated;
		};
	};

	const res = ts.transform(sc, [transformer]);
	assert(res.transformed.length === 1);
	// console.log(chalk.green(debug1(res)));
	const updated = res.transformed[0];

	/** @type {Set<string>} */
	const allIdentifiers = new Set();
	/**
	 * @param {Node} node 
	 */
	function typeReferenceVisitor(node) {
		if (ts.isIdentifier(node)) {
			allIdentifiers.add(node.text);
		}
		node.forEachChild(typeReferenceVisitor);
	}
	updated.forEachChild(typeReferenceVisitor);

	console.log("=========== print ==========");
	console.log(printSourceFile(updated));
	// console.log("ORIGINAL", chalk.yellow(debug1(sc)));
	console.log("------------ getText ---------");
	console.log(updated.getText());
	// console.log("UPDATED", chalk.yellow(debug1(updated)));
	console.log("////////////////////////");
	console.log("allIdentifiers", allIdentifiers);
})();