//@ts-check
/**
 * This is the version that uses ts-morph but it is rather slow right now,
 * So we are switching to fixApiModelImportsV2.js which uses native typescript compiler api.
 */

/**
 * @typedef {import("typescript").Node} Node
 * @typedef {import("typescript").SourceFile} SourceFile
 * @typedef {import("typescript").SyntaxKind} SyntaxKind
 * @typedef {import("typescript").Statement} Statement
 * @typedef {import("typescript").ImportDeclaration} ImportDeclaration
 * @typedef {import("typescript").FunctionDeclaration} FunctionDeclaration
 * @typedef {import("typescript").TransformerFactory<SourceFile>} TransformerFactory
 */

const ts = require("typescript");
const assert = require("assert");
const util = require("util");

const debug0 = (/** @type {any} */ obj) => util.inspect(obj, { depth: 0 });
const debug1 = (/** @type {any} */ obj) => util.inspect(obj, { depth: 1 });

const nodePrinter = ts.createPrinter({ newLine: ts.NewLineKind.LineFeed });

/** @type {(src: SourceFile)=>string} */
const printSourceFile = (src) => nodePrinter.printNode(ts.EmitHint.SourceFile, src, src);

(async () => {
	const code = `
import assert from "assert";

function doit(){
	console.log(window);
}
	`;
	const sc = ts.createSourceFile("./file.ts", code, ts.ScriptTarget.Latest, true);

	/** @type {TransformerFactory} */
	const removeCalls = (context) => {
		return sourceFile => {
			/** @type {(node:Node)=> Node | Node[] | undefined} */
			const visitor = (node) => {
				if (ts.isExpressionStatement(node) && ts.isCallExpression(node.expression)) {
					return;
				}
				return ts.visitEachChild(node, visitor, context);
			};
			return ts.visitNode(sourceFile, visitor);
		};
	};

	const res = ts.transform(sc, [removeCalls]);
	const updated = res.transformed[0];

	/** @type {Set<string>} */
	const allIdentifiers = new Set();
	/**
	 * @param {Node} node 
	 */
	function typeReferenceVisitor(node) {
		if (ts.isIdentifier(node)) {
			allIdentifiers.add(node.text);
		}
		node.forEachChild(typeReferenceVisitor);
	}
	updated.forEachChild(typeReferenceVisitor);

	console.log("=========== print updated ==========");
	console.log(printSourceFile(updated));
	console.log("----------- updated getText --------");
	console.log(updated.getText());
	console.log("-----------------------------------");
	console.log("allIdentifiers:", allIdentifiers);
})();