// @ts-check
const assert = require("assert");
const path = require("path");
const fs = require("fs");
const globby = require("globby");
const _ = require("lodash");

/**
 * @returns {Promise<string[]>}
 */
function get_win_drives() {
    return new Promise((res, rej) => {
        let stdout = "";
        const spawn = require("child_process").spawn;
        const list = spawn("cmd", {
            shell: false,
        });

        list.stdout.on("data", function (data) {
            stdout += data;
        });

        list.stderr.on("data", function (data) {
            console.log("stderr: " + data);
        });

        list.on("exit", function (code) {
            if (code == 0) {
                // console.log(stdout);
                var data = stdout.split("\r\n");
                data = data.splice(4, data.length - 7);
                data = data.map(Function.prototype.call, String.prototype.trim);
                res(data.filter((d) => /^\w:$/.test(d)).map((d) => d.substr(0, 1)));
            } else {
                console.log("child process exited with code " + code);
                rej();
            }
        });
        list.stdin.write("wmic logicaldisk get caption\n");
        list.stdin.end();
    });
}

async function locateMsBuildExe() {
    const drives = await get_win_drives();
    /** @type {string[]} */
    const checkedPaths = [];
    for (const d of drives) {
        // C:\Program Files (x86)\Microsoft Visual Studio\2017\Community\MSBuild\15.0\Bin\MSBuild.exe
        // C:\Program Files (x86)\Microsoft Visual Studio\2019\Community\MSBuild\Current\Bin\MSBuild.exe
        // D:\Program Files (x86)\Microsoft Visual Studio\2017\Community\MSBuild\15.0\Bin\MSBuild.exe

        const vs = path.join(`${d}:\\Program Files (x86)\\Microsoft Visual Studio`);
        if (fs.existsSync(vs)) {
            const versions = (await fs.promises.readdir(vs)).filter((f) => /2\d+/.test(f)).map((f) => parseInt(f, 10));
            if (versions.length) {
                const maxVersion = _.max(versions);
                const directory = path.join(vs, maxVersion.toString());
                checkedPaths.push(directory);
                const matches = await globby("**/Bin/MSBuild.exe", {
                    cwd: directory,
                });
                if (matches.length) {
                    const exe = path.join(directory, matches[0]);
                    assert(fs.existsSync(exe), `${exe} not in disk???`);
                    return exe;
                }
            }
        }
    }
    throw new Error("Failed to locate msbuild.exe, tried paths: " + checkedPaths.join("\r\n"));
}

function makeNugetVersionBuildNo() {
    const now = new Date();
    const pad = (d) => (d.toString().length < 2 ? "0" + d : d.toString());
    const versionNo =
        now.getFullYear().toString().substr(2, 2) +
        pad(now.getMonth() + 1) +
        pad(now.getDate()) +
        "." +
        pad(now.getHours()) +
        pad(now.getMinutes()) +
        pad(now.getSeconds());
    return versionNo;
}
module.exports = {
    get_win_drives,
    locateMsBuildExe,
    makeNugetVersionBuildNo,
};
